==> qtjambi-quick-5.15.4-sources.jar: io/qt/quick/QSGTransformNode.java <==
package io.qt.quick;


/**
 * <p>Implements transformations in the scene graph</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qsgtransformnode.html">QSGTransformNode</a></p>
 */
public class QSGTransformNode extends io.qt.quick.QSGNode
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsgtransformnode.html#QSGTransformNode">QSGTransformNode::QSGTransformNode()</a></p>
     */
    public QSGTransformNode(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSGTransformNode instance);
    
    @io.qt.QtUninvokable
    public final io.qt.gui.QMatrix4x4 combinedMatrix(){
        return combinedMatrix_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QMatrix4x4 combinedMatrix_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsgtransformnode.html#matrix">QSGTransformNode::matrix()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.gui.QMatrix4x4 matrix(){
        return matrix_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QMatrix4x4 matrix_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setCombinedMatrix(io.qt.gui.QMatrix4x4 matrix){
        setCombinedMatrix_native_cref_QMatrix4x4(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(matrix));
    }
    
    @io.qt.QtUninvokable
    private native void setCombinedMatrix_native_cref_QMatrix4x4(long __this__nativeId, long matrix);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsgtransformnode.html#setMatrix">QSGTransformNode::setMatrix(QMatrix4x4)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setMatrix(io.qt.gui.QMatrix4x4 matrix){
        setMatrix_native_cref_QMatrix4x4(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(matrix));
    }
    
    @io.qt.QtUninvokable
    private native void setMatrix_native_cref_QMatrix4x4(long __this__nativeId, long matrix);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSGTransformNode(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private static native String toString_native(long __this_nativeId);
}

==> qtjambi-quick-6.2.10-sources.jar: io/qt/quick/QSGTransformNode.java <==
package io.qt.quick;


/**
 * <p>Implements transformations in the scene graph</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qsgtransformnode.html">QSGTransformNode</a></p>
 */
public class QSGTransformNode extends io.qt.quick.QSGNode
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsgtransformnode.html#QSGTransformNode">QSGTransformNode::QSGTransformNode()</a></p>
     */
    public QSGTransformNode(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSGTransformNode instance);
    
    @io.qt.QtUninvokable
    public final io.qt.gui.QMatrix4x4 combinedMatrix(){
        return combinedMatrix_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QMatrix4x4 combinedMatrix_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsgtransformnode.html#matrix">QSGTransformNode::matrix()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.gui.QMatrix4x4 matrix(){
        return matrix_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QMatrix4x4 matrix_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setCombinedMatrix(io.qt.gui.QMatrix4x4 matrix){
        setCombinedMatrix_native_cref_QMatrix4x4(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(matrix));
    }
    
    @io.qt.QtUninvokable
    private native void setCombinedMatrix_native_cref_QMatrix4x4(long __this__nativeId, long matrix);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsgtransformnode.html#setMatrix">QSGTransformNode::setMatrix(QMatrix4x4)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setMatrix(io.qt.gui.QMatrix4x4 matrix){
        setMatrix_native_cref_QMatrix4x4(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(matrix));
    }
    
    @io.qt.QtUninvokable
    private native void setMatrix_native_cref_QMatrix4x4(long __this__nativeId, long matrix);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSGTransformNode(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private static native String toString_native(long __this_nativeId);
}
